@@ -37,8 +37,8 @@ class Option(BasicActionMixin, BaseOption[T_co]):
 
     :param option_strs: The long and/or short option prefixes for this option.  If no long prefixes are specified,
       then one will automatically be added based on the name assigned to this parameter.
-    :param nargs: The number of values that are expected/required when this parameter is specified.  Defaults to 1.
-      See :class:`.Nargs` for more info.
+    :param nargs: The number of values that are expected/required when this parameter is specified.  Defaults to ``+``
+      when ``action='append'``, and to ``1`` otherwise. See :class:`.Nargs` for more info.
     :param action: The action to take on individual parsed values.  Actions must be defined as methods in classes
       that extend Parameter, and must be registered via :class:`.parameter_action`.  Defaults to ``store`` when
       ``nargs=1``, and to ``append`` otherwise.  A single value will be stored when ``action='store'``, and a list
@@ -74,17 +74,25 @@ class Option(BasicActionMixin, BaseOption[T_co]):
         **kwargs,
     ):
         if nargs is not None:
-            self.nargs = Nargs(nargs)
-        if 0 in self.nargs:
+            self.nargs = nargs = Nargs(nargs)
+        elif action == 'append':
+            self.nargs = nargs = Nargs('+')
+        else:
+            nargs = self.nargs  # default: Nargs(1)
+
+        if 0 in nargs:
+            nargs = nargs._orig
             details = 'use Flag or Counter for Options with 0 args'
             if isinstance(nargs, range) and nargs.start == 0 and nargs.step != nargs.stop:
                 suffix = f', {nargs.step}' if nargs.step != 1 else ''
                 details = f'try using range({nargs.step}, {nargs.stop}{suffix}) instead, or {details}'
             raise ParameterDefinitionError(f'Invalid {nargs=} - {details}')
+
         if action is _NotSet:
-            action = 'store' if self.nargs == 1 else 'append'
-        elif action == 'store' and self.nargs != 1:
-            raise ParameterDefinitionError(f'Invalid nargs={self.nargs} for {action=}')
+            action = 'store' if nargs == 1 else 'append'
+        elif action == 'store' and nargs != 1:
+            raise ParameterDefinitionError(f'Invalid {nargs=} for {action=}')
+
         super().__init__(*option_strs, action=action, default=default, required=required, **kwargs)
         self.type = normalize_input_type(type, choices)
         self._validate_nargs_and_allow_leading_dash(allow_leading_dash)
